#if !defined(AFX_PROPPAGER2DNIS_H__0E8C16E0_64FC_4FEB_B767_156D3B133514__INCLUDED_)
#define AFX_PROPPAGER2DNIS_H__0E8C16E0_64FC_4FEB_B767_156D3B133514__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// PropPageR2Dnis.h : header file
//

// ??? #include "ValueMap.h"
#include "Resource.h"
// ??? #include "ConfigWizPage.h"
#include "dxbtypes.h"
#include "mgmthlc.h"

/////////////////////////////////////////////////////////////////////////////
// CPropPageR2Dnis dialog

class CPropPageR2Dnis : public CPropertyPage
{
	DECLARE_DYNCREATE(CPropPageR2Dnis)

// Construction
public:
	CPropPageR2Dnis();
	~CPropPageR2Dnis();

	void SetMinDnis(DWORD const n) { m_nMinDNIS = n; };
	DWORD GetMinDnis(void) const { return m_nMinDNIS; };

	void SetMaxDnis(DWORD const n) { m_nMaxDNIS = n; };
	DWORD GetMaxDnis(void) const { return m_nMaxDNIS; };

	void SetMinAni(DWORD const n) { m_nMinANI = n; };
	DWORD GetMinAni(void) const { return m_nMinANI; };

	void SetMaxAni(DWORD const n) { m_nMaxANI = n; };
	DWORD GetMaxAni(void) const { return m_nMaxANI; };

	void SetSendANI(DWORD const n) { m_fSendANI = (0 != n); };
	DWORD GetSendANI(void) const { return m_fSendANI ? 1 : 0 ; };

	BOOL OnInitDialog();

// Dialog Data
	//{{AFX_DATA(CPropPageR2Dnis)
	enum { IDD = IDD_PropPgR2_Dnis };
	CButton	m_ctrlSendANI;
	int		m_iMinDNISDigits;
	int		m_iMaxDNISDigits;
	int		m_iMinANIDigits;
	int		m_iMaxANIDigits;
	UINT	m_nMinDNIS;
	UINT	m_nMaxDNIS;
	BOOL	m_fSendANI;
	UINT	m_nMaxANI;
	UINT	m_nMinANI;
	//}}AFX_DATA


// Overrides
	// ClassWizard generate virtual function overrides
	//{{AFX_VIRTUAL(CPropPageR2Dnis)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:
	// Generated message map functions
	//{{AFX_MSG(CPropPageR2Dnis)
		// NOTE: the ClassWizard will add member functions here
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()

};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_PROPPAGER2DNIS_H__0E8C16E0_64FC_4FEB_B767_156D3B133514__INCLUDED_)
